@@ -438,9 +438,58 @@ class PrintableASCIINoBlank(Validator):
             'pascii': '用户名不能为空'
         }
     }
+
+
+class Unblank(Validator):
+    msg = 'unblank'
+
+    message = {
+        'msg': {
+            'unblank': 'msg is not be able to be blank'
+        }
+    }
+
+
 # ======================================================================================================================
 
 
+class UnblankTestCase(TestCase):
+    def setUp(self):
+        self.validator = Unblank
+        self.valid_data = {
+            'msg': 'hello'
+        }
+        self.invalid_data = {
+            'msg': ''
+        }
+
+        self.invalid_data2 = {
+            'msg': '\r\n\r\n'
+        }
+
+        self.invalid_data3 = {
+            'msg2': 'test'
+        }
+
+    def test_valid(self):
+        validator = self.validator(self.valid_data)
+        validator.validate()
+        self.assertTrue(validator.validate())
+
+    def test_invalid(self):
+        validator = self.validator(self.invalid_data)
+        validator.validate()
+        self.assertTrue(validator.get_status())
+
+        validator = self.validator(self.invalid_data2)
+        validator.validate()
+        self.assertFalse(validator.get_status())
+
+        validator = self.validator(self.invalid_data3)
+        validator.validate()
+        self.assertTrue(validator.get_status())
+
+
 class RequiredTestCase(TestCase):
     def setUp(self):
         self.validator = Required
@@ -1551,8 +1600,19 @@ class DecimalTestCase(TestCase):
     def setUp(self):
         self.validator = Decimal
         self.valid_data = {
+            'price': '-123.456'
+        }
+        self.valid_data1 = {
+            'price': '+123.456'
+        }
+        self.valid_data2 = {
             'price': 123.456
         }
+
+        self.valid_data3 = {
+            'price': -123.456
+        }
+
         self.invalid_data = {
             'price': 'abcdef'
         }
@@ -1561,6 +1621,15 @@ class DecimalTestCase(TestCase):
         validator = self.validator(self.valid_data)
         self.assertTrue(validator.validate())
 
+        validator = self.validator(self.valid_data1)
+        self.assertTrue(validator.validate())
+
+        validator = self.validator(self.valid_data2)
+        self.assertTrue(validator.validate())
+
+        validator = self.validator(self.valid_data3)
+        self.assertFalse(validator.validate())
+
         validator = self.validator(self.invalid_data)
         self.assertFalse(validator.validate())
 
