@@ -499,7 +499,23 @@ class DatetimeAfter(BaseRule):
         return datetime.datetime.strptime(datetime_str, self.param_format_str)
 
 
-# FIX: thie required should filter the space in the given value
+class Unblank(BaseRule):
+    name = 'unblank'
+    message = _('{FIELD} field is should not be blank')
+    description = _('the given field should not be blank')
+
+    def check_null(self):
+        pass
+
+    def check_value(self):
+        try:
+            value_str = str(self.field_value).strip()
+        except ValueError:
+            value_str = ''
+
+        self.status = True if value_str else False
+
+
 class Required(BaseRule):
     name = 'required'
     message = _('{FIELD} field is required')
@@ -516,6 +532,7 @@ class Required(BaseRule):
 
         self.status = True if value_str else False
 
+
 class Accepted(BaseRule):
     name = 'accepted'
     message = _('{VALUE} of {FIELD} field must in which of : {FLAGS}')
@@ -1140,13 +1157,13 @@ class Decimal(BaseRule):
         self.status = self.check_decimal()
 
     def check_decimal(self):
-        r = r'^[0-9]+(\.[0-9]+)?$'
+        r = r'^([\+\-])?[0-9]+(\.[0-9]+)?$'
         m = re.fullmatch(r, str(self.field_value))
 
         return True if m else False
 
     def check_null(self):
-        self.check()
+        pass
 
     def check_value(self):
         self.check()
@@ -1334,5 +1351,6 @@ default_rules = {
     Decimal.get_name(): Decimal,
     Exist.get_name(): Exist,
     UniqueAgainst.get_name(): UniqueAgainst,
-    PrintableASCII.get_name(): PrintableASCII
+    PrintableASCII.get_name(): PrintableASCII,
+    Unblank.get_name(): Unblank
 }
